@@ -10,6 +10,15 @@
 CircuitPython module for the MCP23008 I2C I/O extenders.
 
 * Author(s): Tony DiCola
+
+Implementation Notes
+--------------------
+
+**Hardware:**
+
+* `MCP23008 - i2c 8 input/output port expander
+  <https://www.adafruit.com/product/593>`_
+
 """
 
 from micropython import const
@@ -22,7 +31,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "2.5.8"
+__version__ = "2.5.9"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_MCP230xx.git"
 
 _MCP23008_ADDRESS = const(0x20)
