@@ -12,6 +12,18 @@
 CircuitPython module for the MCP23017 I2C I/O extenders.
 
 * Author(s): Tony DiCola
+
+Implementation Notes
+--------------------
+
+**Hardware:**
+
+* `MCP23017 - i2c 16 input/output port expander
+  <https://www.adafruit.com/product/732>`_
+
+* `Adafruit MCP23017 I2C GPIO Expander Breakout - STEMMA QT / Qwiic
+  <https://www.adafruit.com/product/5346>`_
+
 """
 
 from micropython import const
@@ -24,7 +36,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "2.5.8"
+__version__ = "2.5.9"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_MCP230xx.git"
 
 _MCP23017_ADDRESS = const(0x20)
